@@ -40,7 +40,8 @@ def gridFunction(view,name,order):
     def gridFunction_decorator(func):
         gf = dune.grid.gridFunction(view,name=name,order=order)(func)
         setattr(gf.__class__,"as_ufl", lambda self: dune.ufl.GridFunction(self))
-        setattr(gf.__class__,"integrate", lambda self: 0) # uflFunction(view,"tmp",order,self).integrate())
+        setattr(gf.__class__,"integrate", lambda self: uflFunction(view,"tmp",order,self).integrate())
+        gf.__class__.gridView = property(lambda self: self.grid)
         return gf.as_ufl()
     return gridFunction_decorator
 # this is not going to work - needs fixing
@@ -89,18 +90,28 @@ def cppFunction(gridView, name, order, fctName, includes,
                 *args,**kwargs):
     args = args + tuple(kwargs.get("args",()))
     gf = gridView.function(fctName,includes,*args,order=order,name=name)
+    gf.__class__.gridView = property(lambda self: self.grid)
     return dune.ufl.GridFunction( gf )
 
 def _assertSizesMatch(space, dofVector):
-
     # only allow contiguous arrays as dof vectors
-    assert dofVector.data.contiguous, "dofVector needs to provide a contiguous data memory, sliced arrays are not supported!"
+    try:
+        assert dofVector.data.contiguous, "dofVector needs to provide a contiguous data memory, sliced arrays are not supported!"
+    except AttributeError:
+        pass
 
     # only allow arrays with one dimensional shapes
-    assert len(dofVector.shape) == 1, "dofVector should be a simple array, i.e. len(shape) == 1"
+    try:
+        assert len(dofVector.shape) == 1, "dofVector should be a simple array, i.e. len(shape) == 1"
+    except AttributeError:
+        pass
 
     # check that sizes and data size match
-    assert space.size == len(dofVector), f"space (size={space.size}) and vector (size={len(dofVector)}) do not match!"
+    try:
+        assert space.size == len(dofVector), f"space (size={space.size}) and vector (size={len(dofVector)}) do not match!"
+    except TypeError:
+        assert space.size == dofVector.size, f"space (size={space.size}) and vector (size={dofVector.size}) do not match!"
+
     if hasattr(dofVector, "dtype"):
         dtype = dofVector.dtype
         itemsize = np_dtype(dofVector.dtype).itemsize
